@@ -226,8 +226,15 @@ impl<'c> Iterator for BinColumnIt<'c> {
             ret
         }
     }
+    
+    fn size_hint(&self) -> (usize, Option<usize>) {
+        let len = self.num_rows - self.pos;
+        (len, Some(len))
+    }
 }
 
+impl<'c> ExactSizeIterator for BinColumnIt<'c> {}
+
 /// Fills a binary column buffer with elements from an Iterator. See
 /// [`crate::buffers::AnyColumnViewMut`]
 #[derive(Debug)]
