@@ -8,8 +8,8 @@ use crate::{
     CursorImpl, Error, ParameterCollection,
 };
 
-/// Shared implementation for executing a query with parameters between [`Connection`],
-/// [`Preallocated`] and [`Prepared`].
+/// Shared implementation for executing a query with parameters between [`crate::Connection`],
+/// [`crate::Preallocated`] and [`crate::Prepared`].
 ///
 /// # Parameters
 ///
@@ -73,15 +73,15 @@ where
     }
 }
 
-/// Shared implementation for executing a columns query between [`Connection`] and
-/// [`Preallocated`].
+/// Shared implementation for executing a columns query between [`crate::Connection`] and
+/// [`crate::Preallocated`].
 pub fn columns<'o, S>(
     mut statement: S,
     catalog_name: &U16Str,
     schema_name: &U16Str,
     table_name: &U16Str,
     column_name: &U16Str,
-) -> Result<Option<CursorImpl<'o, S>>, Error>
+) -> Result<CursorImpl<'o, S>, Error>
 where
     S: BorrowMut<StatementImpl<'o>>,
 {
@@ -89,10 +89,8 @@ where
 
     stmt.columns(catalog_name, schema_name, table_name, column_name)?;
 
-    // Check if a result set has been created.
-    if stmt.num_result_cols()? == 0 {
-        Ok(None)
-    } else {
-        Ok(Some(CursorImpl::new(statement)))
-    }
+    // We assume columns always creates a result set, since it works like a SELECT statement.
+    debug_assert_ne!(stmt.num_result_cols().unwrap(), 0);
+
+    Ok(CursorImpl::new(statement))
 }
